# 网易云信 Flutter插件

## 依赖
```yaml
dependencies:
  flutter:
    sdk: flutter
  nim_fluttify: ^x.x.x
```

## 配置
### Android
1. 在AndroidManifest.xml的application标签下配置app key:
```xml
<application>
    <meta-data
            android:name="com.netease.nim.appKey"
            android:value="6cxxxxxxxxxxxxxxxxxxxxxxxxxx9e" />
</application>
```
2. 由于SDK限制, 必须在Application中初始化, 所以需要重新指定Application的实现类, 需要用户继承`FlutterApplication`并重写`onCreate`方法, 然后在AndroidManifest.xml中配置自己实现的Application, 示例实现:
```java
import com.netease.nimlib.sdk.NIMClient;
import com.netease.nimlib.sdk.SDKOptions;

public class NIMApplication extends FlutterApplication {
    @Override
    @CallSuper
    public void onCreate() {
        super.onCreate();
        SDKOptions options = new SDKOptions();
        NIMClient.config(this, null, options);
    }
}
```
最终的AndroidManifest.xml中, 至少需要包含如下信息:
```xml
<application android:name="NIMApplication">
    <meta-data
            android:name="com.netease.nim.appKey"
            android:value="6cxxxxxxxxxxxxxxxxxxxxxxxxxx9e" />
</application>
```
3. 云信最低支持minSdk为17, Flutter默认为16, 所以需要修改app/build.gradle下的minSdkVersion为17.
```groovy
android {
    defaultConfig {
        minSdkVersion 17 // 原本为16, 改为17
    }
}
```
4. AndroidManifest.xml不需要用户再声明权限和官方提及的组件, 已经在插件中声明;
5. 不需要再配置混淆规则, 已在插件中配置混淆规则;

### iOS
1. 选择图片时需要配置访问相册的权限, 在Info.plist中添加相册权限:
```xml
<key>NSPhotoLibraryUsageDescription</key>
<string>需要相册权限</string>
```
2. Flutter默认的最低支持版本是iOS 8.0, 云信的最低支持版本是iOS 9.0. 所以需要更改Podfile:
```ruby
# Uncomment this line to define a global platform for your project
# platform :ios, '9.0'
```
改为(即去掉注释)
```ruby
# Uncomment this line to define a global platform for your project
platform :ios, '9.0'
```

## 导入
```dart
import 'package:nim_fluttify/nim_fluttify.dart';
```

## 使用
插件的主要类为Nim类, Nim类为单例, 调用时使用`Nim.instance.xxx`来使用.

## 初始化
Android端的appkey需要在`AndroidManifest.xml`中配置, 详情参考[权限与组件](https://dev.yunxin.163.com/docs/product/IM%E5%8D%B3%E6%97%B6%E9%80%9A%E8%AE%AF/SDK%E5%BC%80%E5%8F%91%E9%9B%86%E6%88%90/Android%E5%BC%80%E5%8F%91%E9%9B%86%E6%88%90/%E9%9B%86%E6%88%90%E6%96%B9%E5%BC%8F?#%E6%9D%83%E9%99%90%E4%B8%8E%E7%BB%84%E4%BB%B6).
iOS端的appkey在`Nim.instance.init`方法中传入即可.

|       | 社区版 | 付费版 |
|:-----:|:-----:|:-----:|
|  登录  |  ✅ |  ✅   |